@@ -15,7 +15,7 @@ module MiniMagick
     # methods.
     #
     # Use this to pass in a stream object. Must respond to #read(size) or be a
-    # binary string object (BLOBBBB)
+    # binary string object (BLOB)
     #
     # Probably easier to use the {.open} method if you want to open a file or a
     # URL.
@@ -274,7 +274,7 @@ module MiniMagick
     #
     attribute :resolution
     ##
-    # Returns the message digest of this image as a SHA-256, hexidecimal
+    # Returns the message digest of this image as a SHA-256, hexadecimal
     # encoded string. This signature uniquely identifies the image and is
     # convenient for determining if an image has been modified or whether two
     # images are identical.
@@ -340,13 +340,18 @@ module MiniMagick
     #
     # 1) one for each row of pixels
     # 2) one for each column of pixels
-    # 3) three elements in the range 0-255, one for each of the RGB color channels
+    # 3) three or four elements in the range 0-255, one for each of the RGB(A) color channels
     #
     # @example
     #   img = MiniMagick::Image.open 'image.jpg'
     #   pixels = img.get_pixels
     #   pixels[3][2][1] # the green channel value from the 4th-row, 3rd-column pixel
     #
+    # @example
+    #   img = MiniMagick::Image.open 'image.jpg'
+    #   pixels = img.get_pixels("RGBA")
+    #   pixels[3][2][3] # the alpha channel value from the 4th-row, 3rd-column pixel
+    #
     # It can also be called after applying transformations:
     #
     # @example
@@ -357,19 +362,22 @@ module MiniMagick
     #
     # In this example, all pixels in pix should now have equal R, G, and B values.
     #
+    # @param map [String] A code for the mapping of the pixel data. Must be either
+    #   'RGB' or 'RGBA'. Default to 'RGB'
     # @return [Array] Matrix of each color of each pixel
-    def get_pixels
+    def get_pixels(map="RGB")
+      raise ArgumentError, "Invalid map value" unless ["RGB", "RGBA"].include?(map)
       convert = MiniMagick::Tool::Convert.new
       convert << path
       convert.depth(8)
-      convert << "RGB:-"
+      convert << "#{map}:-"
 
       # Do not use `convert.call` here. We need the whole binary (unstripped) output here.
       shell = MiniMagick::Shell.new
       output, * = shell.run(convert.command)
 
       pixels_array = output.unpack("C*")
-      pixels = pixels_array.each_slice(3).each_slice(width).to_a
+      pixels = pixels_array.each_slice(map.length).each_slice(width).to_a
 
       # deallocate large intermediary objects
       output.clear
@@ -378,6 +386,23 @@ module MiniMagick
       pixels
     end
 
+    ##
+    # This is used to create image from pixels. This might be required if you
+    # create pixels for some image processing reasons and you want to form 
+    # image from those pixels.
+    #
+    # *DANGER*: This operation can be very expensive. Please try to use with
+    # caution. 
+    # 
+    # @example
+    #   # It is given in readme.md file
+    ##
+    def self.get_image_from_pixels(pixels, dimension, map, depth, mime_type)
+      pixels = pixels.flatten
+      blob = pixels.pack('C*')
+      import_pixels(blob, *dimension, depth, map, mime_type)
+    end
+
     ##
     # This is used to change the format of the image. That is, from "tiff to
     # jpg" or something like that. Once you run it, the instance is pointing to
@@ -436,6 +461,9 @@ module MiniMagick
       @info.clear
 
       self
+    rescue MiniMagick::Invalid, MiniMagick::Error => e
+      new_tempfile.unlink if new_tempfile && @tempfile != new_tempfile
+      raise e
     end
 
     ##
