@@ -14,7 +14,7 @@ module MiniMagick
     #
     def which(cmd)
       exts = ENV['PATHEXT'] ? ENV['PATHEXT'].split(';') : ['']
-      ENV['PATH'].split(File::PATH_SEPARATOR).each do |path|
+      ENV.fetch('PATH').split(File::PATH_SEPARATOR).each do |path|
         exts.each do |ext|
           exe = File.join(path, "#{cmd}#{ext}")
           return exe if File.executable? exe
@@ -24,7 +24,7 @@ module MiniMagick
     end
 
     def tempfile(extension)
-      Tempfile.new(["mini_magick", extension]).tap do |tempfile|
+      Tempfile.new(["mini_magick", extension], MiniMagick.tmpdir).tap do |tempfile|
         tempfile.binmode
         yield tempfile if block_given?
         tempfile.close
